--
-- DieselKanister
-- Specialization for a DieselKanister
--




DieselKanister = {};

function DieselKanister.prerequisitesPresent(specializations)
    return SpecializationUtil.hasSpecialization(Trailer, specializations);
end;

function DieselKanister:load(xmlFile)

	self.gasRefillTriggerCallback = DieselKanister.gasRefillTriggerCallback;
	self.trigger = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.serviceTrailerParts.refillTrigger#index"));	
	addTrigger(self.trigger, "gasRefillTriggerCallback", self);
    self.deleteListenerId = addDeleteListener(self.trigger, "delete", self);
	self.fuelCapacity = Utils.getNoNil(getXMLFloat(xmlFile, "vehicle.fuelCapacity"), 500);
	self.refuelSpeed = Utils.getNoNil(getXMLFloat(xmlFile, "vehicle.refuelSpeed"), 0.0001);
	self.steerablesInRange = {};
	
	self.moneyBackup = {};
	self.moneyBackup.expensesTotal = 0;
	self.moneyBackup.expensesSession = 0;
	self.moneyBackup.money = 0;
	
    self.refuelSampleRunning = false;
    self.refuelSample = createSample("refuelSample");
	local soundFile = Utils.getNoNil(getXMLString(xmlFile, "vehicle.serviceTrailerParts.refillTrigger.refillSound"),"$data/maps/sounds/refuel.wav");
    loadSample(self.refuelSample, Utils.getFilename(soundFile, self.baseDirectory), false); 
	
	self.tankFillLevel = 0;
	self.isRefilling = false;
	self.capacity = self.fuelCapacity;	
	fruitTypes = kanisterdiesel;
end;

function DieselKanister:delete()
    removeTrigger(self.trigger);
    removeDeleteListener(self.trigger, self.deleteListenerId);
end;

function DieselKanister:mouseEvent(posX, posY, isDown, isUp, button)
end;

function DieselKanister:keyEvent(unicode, sym, modifier, isDown)
end;

function DieselKanister:update(dt)
	for k, steerable in pairs(self.steerablesInRange) do
		if steerable.obj.doRefuel then
			if self.tankFillLevel > 0 then
				local delta = steerable.obj.fuelFillLevel - steerable.oldFuelLevel;
				self.tankFillLevel = self.tankFillLevel - delta;
				steerable.oldFuelLevel = steerable.obj.fuelFillLevel;
				delta = delta*g_fuelPricePerLiter;
				g_currentMission.missionStats.expensesTotal = g_currentMission.missionStats.expensesTotal - delta;
				g_currentMission.missionStats.expensesSession = g_currentMission.missionStats.expensesSession - delta;
				g_currentMission.missionStats.money = g_currentMission.missionStats.money + delta;
			else
				steerable.obj.fuelFillLevel = steerable.oldFuelLevel;
			end;
			if self.tankFillLevel <= 0 then
				steerable.obj:stopRefuel();
				self.tankFillLevel = 0;
			end;
		end;	
	end;	
	if self:getIsActive() then
		if g_currentMission.currentVehicle ~= nil then
			self.isTrailerInRefillRange = g_currentMission.currentVehicle.hasRefuelStationInRange;
			
			if self.isTrailerInRefillRange then
				if InputBinding.hasEvent(InputBinding.FILL_DIESEL_TRAILER) then
					self.isRefilling = not self.isRefilling;
					if self.tankFillLevel > self.fuelCapacity then
						self.isRefilling = false;
					end;
				end;
			else
				self.isRefilling = false;
			end;	

			if self.isRefilling then
			
				if not self.refuelSampleRunning and self:getIsActiveForSound() then
					playSample(self.refuelSample, 0, 1, 0);
					self.refuelSampleRunning = true;
				end;
				local refuelSpeed = 0.01;
				local currentFillLevel = self.tankFillLevel;
				self.tankFillLevel = self.tankFillLevel + refuelSpeed * dt;
				local delta = (self.tankFillLevel-currentFillLevel);

				if self.tankFillLevel >= self.fuelCapacity then
					self.tankFillLevel = self.fuelCapacity;
					self.isRefilling = false;
				end;
				delta = delta * g_fuelPricePerLiter;
				g_currentMission.missionStats.expensesTotal = g_currentMission.missionStats.expensesTotal + delta;
				g_currentMission.missionStats.expensesSession = g_currentMission.missionStats.expensesSession + delta;
				g_currentMission.missionStats.money = g_currentMission.missionStats.money - delta;	
			else
				if self.refuelSampleRunning then
					stopSample(self.refuelSample);
					self.refuelSampleRunning = false;
				end;
			end;
		end;		
	end;	
	------------ set the tanklevel to current filllevel from Trailer--------------------------------------
	
	self.fillLevel = self.tankFillLevel;
	
	if self.tankFillLevel >0 then
	
	self.currentFillType = FruitUtil.FRUITTYPE_KANISTERDIESEL;
	
		end;
	
	----------------------------------------------------------------------------------------------------------------
end;

function DieselKanister:draw()
	if self.isTrailerInRefillRange then
		if self.isRefilling then
			g_currentMission:addHelpButtonText(g_i18n:getText("Kanister_stop_refill"), InputBinding.FILL_DIESEL_TRAILER);
		else
			g_currentMission:addHelpButtonText(g_i18n:getText("Kanister_start_refill"), InputBinding.FILL_DIESEL_TRAILER);
		end;
	end;
end;

function DieselKanister:gasRefillTriggerCallback(triggerId, otherId, onEnter, onLeave, onStay, otherShapeId)
	if g_currentMission.currentVehicle ~= nil then
		if onEnter then
			if g_currentMission.currentVehicle.rootNode == otherId then
			
				local vehicle = {};
				vehicle.obj = g_currentMission.currentVehicle;
				vehicle.oldFuelLevel = g_currentMission.currentVehicle.fuelFillLevel;
				self.steerablesInRange[otherId] = vehicle;
				g_currentMission.currentVehicle.hasRefuelStationInRange = true;
			end;
		elseif onLeave then
			local leavingVehicle = self.steerablesInRange[otherId];
			if leavingVehicle ~= nil then
				leavingVehicle.obj.hasRefuelStationInRange = false;
			end;
		end;
	end;
end;

function DieselKanister:loadFromAttributesAndNodes(xmlFile, key, resetVehicles)
	if not resetVehicles then
		local value = getXMLFloat(xmlFile, key.."#fuelTankFillLevel");		
		if value ~= nil then
			self.tankFillLevel = value;			
		end;
	end; 
    return BaseMission.VEHICLE_LOAD_OK;
end;

function DieselKanister:getSaveAttributesAndNodes(nodeIdent)	
	local attributes = 'fuelTankFillLevel="'.. self.tankFillLevel ..'"';
	
    return attributes, nil;
	
end;


